/* eslint-disable react/jsx-handler-names */
/* eslint-disable react/destructuring-assignment */
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import KeyFilter from 'primereact/components/keyfilter/KeyFilter';
import Tooltip from 'primereact/tooltip';
import DomHandler from 'primereact/components/utils/DomHandler';
import ObjectUtils from 'primereact/components/utils/ObjectUtils';

export class InputText extends Component {
	constructor(props) {
		super(props);
		this.onInput = this.onInput.bind(this);
		this.onKeyPress = this.onKeyPress.bind(this);
	}

	componentDidMount() {
		if (this.props.tooltip) {
			this.renderTooltip();
		}
	}

	componentDidUpdate(prevProps) {
		if (prevProps.tooltip !== this.props.tooltip) {
			if (this.tooltip) this.tooltip.updateContent(this.props.tooltip);
			else this.renderTooltip();
		}
	}

	componentWillUnmount() {
		if (this.tooltip) {
			this.tooltip.destroy();
			this.tooltip = null;
		}
	}

	onKeyPress(event) {
		if (this.props.onKeyPress) {
			this.props.onKeyPress(event);
		}

		if (this.props.keyfilter) {
			KeyFilter.onKeyPress(event, this.props.keyfilter, this.props.validateOnly);
		}
	}

	onInput(event) {
		let validatePattern = true;
		if (this.props.keyfilter && this.props.validateOnly) {
			validatePattern = KeyFilter.validate(event, this.props.keyfilter);
		}

		if (this.props.onInput) {
			this.props.onInput(event, validatePattern);
		}

		if (!this.props.onChange) {
			if (event.target.value.length > 0) DomHandler.addClass(event.target, 'p-filled');
			else DomHandler.removeClass(event.target, 'p-filled');
		}
	}

	renderTooltip() {
		this.tooltip = new Tooltip({
			target: this.element,
			content: this.props.tooltip,
			options: this.props.tooltipOptions,
		});
	}

	render() {
		const className = classNames('p-inputtext p-component', this.props.className, {
			'p-disabled': this.props.disabled,
			'p-filled':
				(this.props.value != null && this.props.value.toString().length > 0) ||
				(this.props.defaultValue != null && this.props.defaultValue.toString().length > 0),
		});

		const inputProps = ObjectUtils.findDiffKeys(this.props, InputText.defaultProps);
		if (inputProps !== undefined) {
			delete inputProps.ariaDescribedBy;
			delete inputProps.ariaLabelledBy;
			delete inputProps.ariaLabel;
		}
		return (
			<input
				ref={el => (this.element = el)}
				{...inputProps}
				className={className}
				onInput={this.onInput}
				onKeyPress={this.onKeyPress}
				aria-label={this.props.ariaLabel}
				aria-labelledby={this.props.ariaLabelledBy}
				aria-describedby={this.props.ariaDescribedBy}
				required={this.props.required}
				aria-required={this.props.required}
				autoComplete="off"
			/>
		);
	}
}

InputText.defaultProps = {
	onInput: null,
	onKeyPress: null,
	keyfilter: null,
	validateOnly: false,
	tooltip: null,
	tooltipOptions: null,
};

InputText.propTypes = {
	ariaDescribedBy: PropTypes.string,
	ariaLabel: PropTypes.string,
	ariaLabelledBy: PropTypes.string,
	className: PropTypes.string,
	defaultValue: PropTypes.any,
	disabled: PropTypes.bool,
	keyfilter: PropTypes.any,
	onChange: PropTypes.func,
	onInput: PropTypes.func,
	onKeyPress: PropTypes.func,
	required: PropTypes.bool,
	tooltip: PropTypes.string,
	tooltipOptions: PropTypes.object,
	validateOnly: PropTypes.bool,
	value: PropTypes.any,
};

export default InputText;
